==> viennaps-3.1.0-pp38-pypy38_pp73-macosx_11_0_arm64.whl: viennaps.libs/common/cmake_install.cmake <==
# Install script for directory: /Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-src/common

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/var/folders/m_/cksx93ys47x4621g0zbw_m4m0000gn/T/tmpjxdo_6i1/wheel/platlib")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "Release")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

# Set path to fallback-tool for dependency-resolution.
if(NOT DEFINED CMAKE_OBJDUMP)
  set(CMAKE_OBJDUMP "/Applications/Xcode_15.4.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/objdump")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/sys/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/math/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/simd/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/lexers/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/tasking/cmake_install.cmake")

endif()

==> viennaps-3.2.0-pp38-pypy38_pp73-macosx_11_0_arm64.whl: viennaps.libs/common/cmake_install.cmake <==
# Install script for directory: /Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-src/common

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/var/folders/g6/rgtlsw6n123b0gt5483s5_cm0000gn/T/tmpouf6pebu/wheel/platlib")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "Release")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

# Set path to fallback-tool for dependency-resolution.
if(NOT DEFINED CMAKE_OBJDUMP)
  set(CMAKE_OBJDUMP "/usr/bin/objdump")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/sys/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/math/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/simd/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/lexers/cmake_install.cmake")
  include("/Users/runner/work/ViennaPS/ViennaPS/build/_deps/embree-build/common/tasking/cmake_install.cmake")

endif()
